@@ -2,7 +2,7 @@ package XHTML::Util;
 use strict;
 use warnings;
 no warnings "uninitialized";
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 use Encode;
 use Carp; # By verbosity?
 use Scalar::Util "blessed";
@@ -406,7 +406,7 @@ XHTML::Util - (alpha software) powerful utilities for common but difficult to na
 
 =head2 VERSION
 
-0.03
+0.04
 
 =head1 SYNOPSIS
 
@@ -569,7 +569,7 @@ That said, a lot of the code herein is not well tested or at least not well test
 
 L<XML::LibXML>, L<HTML::Tagset>, L<HTML::Entities>, L<HTML::Selector::XPath>, L<HTML::TokeParser::Simple>, L<CSS::Tiny>.
 
-L<CSS W3Schools|http://www.w3schools.com/Css/default.asp>, L<Learning CSS at W3C|http://www.w3.org/Style/CSS/learning>.
+CSS W3Schools, L<http://www.w3schools.com/Css/default.asp>, Learning CSS at W3C, L<http://www.w3.org/Style/CSS/learning>.
 
 =head1 AUTHOR
 
@@ -624,6 +624,44 @@ delete @Charmap{qw( amp lt gt quot apos )};
 
 #  LocalWords:  xpath
 
+use Test::More tests => 1;
+
+XML::LibXML based only at first because it's easier.
+
+actual markup
+remove_markup("leaving content")
+
+entire Nodes
+remove_tags("
+
+enpara
+
+translate_tags
+
+traverse("/*") -> callback
+
+strip_styles(* or [list])
+strip_attributes()
+
+inline_stylesheets(names/paths)
+
+fragment_to_xhtml
+
+
+We WILL NOT be covering other well known and well done implementations like HTML::Entities or URI::Escape
+
+   use Rose::HTML::Util qw(:all);
+
+   $esc = escape_html($str);
+   $str = unescape_html($esc);
+
+   $esc = escape_uri($str);
+   $str = unescape_uri($esc);
+
+   $comp = escape_uri_component($str);
+
+   $esc = encode_entities($str);
+
 # Two ways to get doc together. Pass through HTML::TokeParser first to
 # correct for nothing but HTML and escape the rest.
 
@@ -635,3 +673,4 @@ delete @Charmap{qw( amp lt gt quot apos )};
 
 HTML TO XHTML will have to strip depracated shite like center and font.
 
+
